==> ideaIC-173.4301.1-sources.jar: com/intellij/notification/impl/actions/ShowDelayedMessageInternalAction.java <==
/*
 * Copyright 2000-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.notification.impl.actions;

import com.intellij.CommonBundle;
import com.intellij.openapi.actionSystem.AnAction;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.application.ApplicationBundle;
import com.intellij.openapi.project.DumbAware;
import com.intellij.openapi.ui.MessageDialogBuilder;
import com.intellij.util.TimeoutUtil;

import javax.swing.*;

/**
 * @author Denis Fokin
 */
public class ShowDelayedMessageInternalAction extends AnAction implements DumbAware{
  @Override
  public void actionPerformed(AnActionEvent e) {

    new Thread("show delayed msg") {
      @Override
      public void run() {
        super.run();

        //noinspection EmptyCatchBlock
        TimeoutUtil.sleep(3000);

        //noinspection SSBasedInspection
        SwingUtilities.invokeLater(() -> MessageDialogBuilder.yesNo("Nothing happens after that", "Some message goes here").yesText(
          ApplicationBundle.message("command.exit")).noText(
          CommonBundle.message("button.cancel")).show());
      }
    }.start();

  }
}

==> ideaIC-183.2407.10-sources.jar: com/intellij/notification/impl/actions/ShowDelayedMessageInternalAction.java <==
/*
 * Copyright 2000-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.notification.impl.actions;

import com.intellij.CommonBundle;
import com.intellij.openapi.actionSystem.AnAction;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.application.ApplicationBundle;
import com.intellij.openapi.project.DumbAware;
import com.intellij.openapi.ui.MessageDialogBuilder;
import com.intellij.util.TimeoutUtil;
import org.jetbrains.annotations.NotNull;

import javax.swing.*;

/**
 * @author Denis Fokin
 */
public class ShowDelayedMessageInternalAction extends AnAction implements DumbAware{
  @Override
  public void actionPerformed(@NotNull AnActionEvent e) {

    new Thread("show delayed msg") {
      @Override
      public void run() {
        super.run();

        //noinspection EmptyCatchBlock
        TimeoutUtil.sleep(3000);

        //noinspection SSBasedInspection
        SwingUtilities.invokeLater(() -> MessageDialogBuilder.yesNo("Nothing happens after that", "Some message goes here").yesText(
          ApplicationBundle.message("command.exit")).noText(
          CommonBundle.message("button.cancel")).show());
      }
    }.start();

  }
}
